@@ -66,6 +66,19 @@ class DPModelInspector:
                 message="Model contains LSTM layers. It is recommended that they are"
                 "replaced with DPLSTM",
             ),
+            # Inspector to check that the module is in training mode
+            ModelInspector(
+                name="train_mode",
+                predicate=_is_in_training_mode,
+                message=(
+                    "Your model must be in training mode for the PrivacyEngine to compute "
+                    "per-sample gradients. You can put your model in training mode by simply calling "
+                    "module.train(). If you have part of the model that you want to keep frozen, "
+                    "the best approach is to split your model into a frozen backbone and a trainable "
+                    "head and passing only the head to the optimizer and PrivacyEngine. See an example "
+                    "in this colab: https://bit.ly/opacus-dev-day"
+                ),
+            ),
         ]
 
     def validate(self, model: nn.Module) -> bool:
@@ -116,17 +129,41 @@ class DPModelInspector:
 
 def _is_valid_check(module: nn.Module) -> bool:
     r"""
-    Checks if the ``module``  is supported by ``autograd_grad_sample``
+    Checks if the ``module`` is supported by ``autograd_grad_sample``
+
+    Args:
+        module: The model to validate.
+
+    Returns:
+        True if ``module`` is supported by ``autograd_grad_sample``
     """
     return is_supported(module)
 
 
+def _is_in_training_mode(module: nn.Module) -> bool:
+    r"""
+    Checks if the ``module`` is in train mode
+
+    Args:
+        module: The model to validate.
+
+    Returns:
+        True if ``module`` is in train mode
+    """
+    return module.training
+
+
 def _conv_group_number_check(module: nn.Module) -> bool:
     r"""
-    Checks if number of groups in `nn.Conv2d` layer is valid
+    Checks if number of groups in ``nn.Conv2d`` layer is valid
+
+    Args:
+        module: The input module (layer) for which the check occurs.
+
+    Returns:
+        True if number of groups in ``nn.Conv2d`` layer of ``module`` is valid
     """
     if isinstance(module, nn.Conv2d):
-        # pyre-fixme[16]: `Conv2d` has no attribute `in_channels`.
         return module.groups == 1 or module.groups == module.in_channels
 
     return True
@@ -134,16 +171,31 @@ def _conv_group_number_check(module: nn.Module) -> bool:
 
 def _no_batchnorm_check(module: nn.Module) -> bool:
     r"""
-    Checks if the module is not BatchNorm.
+    Checks if the input module is not BatchNorm.
 
-    This check overlaps with `_is_valid_check`, but provides more targeted remedy.
+    This check overlaps with ``_is_valid_check``, but provides more targeted remedy.
+
+    Args:
+        module: The input module
+
+    Returns:
+        True if the input module is not BatchNorm
     """
     return not isinstance(module, nn.modules.batchnorm._BatchNorm)
 
 
 def _no_running_stats_instancenorm_check(module: nn.Module) -> bool:
     r"""
-    Checks that InstanceNorm layer has `track_running_stats` set to False
+    Checks that ``InstanceNorm`` layer has ``track_running_stats`` set to False
+
+    Args:
+        module: The input module (layer) for which the check is verified.
+
+    Returns:
+        True if the module is not ``InstanceNorm``, otherwise it returns
+        True if the module (layer) have ``track_running_stats`` set to False,
+        and False otherwise.
+
     """
     is_instancenorm = get_layer_type(module) in (
         "InstanceNorm1d",
@@ -152,12 +204,20 @@ def _no_running_stats_instancenorm_check(module: nn.Module) -> bool:
     )
 
     if is_instancenorm:
-        # pyre-fixme[16]: `Module` has no attribute `track_running_stats`.
         return not module.track_running_stats
     return True
 
 
-def _no_lstm(module: nn.Module):
+def _no_lstm(module: nn.Module) -> bool:
+    r"""
+    Checks if the input module is not LSTM.
+
+    Args:
+        module: The input module
+
+    Returns:
+        True if the input module is not LSTM
+    """
     is_lstm = True if get_layer_type(module) == "LSTM" else False
 
     return not is_lstm
