@@ -65,14 +65,13 @@ class DocstringExamplesTest(unittest.TestCase):
         # the docstring for opacus.privacy_engine.PrivacyEngine
         batch_size = 8
         sample_size = 64
+        sample_rate = batch_size / sample_size
 
         model = torch.nn.Linear(16, 32)  # An example model
         optimizer = torch.optim.SGD(model.parameters(), lr=0.05)
         privacy_engine = PrivacyEngine(
             model,
-            batch_size,
-            sample_size,
-            alphas=range(2, 32),
+            sample_rate=sample_rate,
             noise_multiplier=1.3,
             max_grad_norm=1.0,
         )
@@ -83,13 +82,12 @@ class DocstringExamplesTest(unittest.TestCase):
         # the docstring for opacus.privacy_engine.PrivacyEngine.to()
         batch_size = 8
         sample_size = 64
+        sample_rate = batch_size / sample_size
 
         model = torch.nn.Linear(16, 32)  # An example model. Default device is CPU
         privacy_engine = PrivacyEngine(
             model,
-            batch_size,
-            sample_size,
-            alphas=range(5, 64),
+            sample_rate=sample_rate,
             noise_multiplier=0.8,
             max_grad_norm=0.5,
         )
@@ -106,6 +104,7 @@ class DocstringExamplesTest(unittest.TestCase):
         dataloader = []
         batch_size = 64
         sample_size = 256
+        sample_rate = batch_size / sample_size
 
         for _ in range(64):
             data = torch.randn(4, 16)
@@ -117,9 +116,7 @@ class DocstringExamplesTest(unittest.TestCase):
 
         privacy_engine = PrivacyEngine(
             model,
-            batch_size,
-            sample_size,
-            alphas=range(5, 64),
+            sample_rate=sample_rate,
             noise_multiplier=0.8,
             max_grad_norm=0.5,
         )
@@ -152,7 +149,6 @@ class DocstringExamplesTest(unittest.TestCase):
     def test_module_modification_replace_example(self):
         # IMPORTANT: When changing this code you also need to update
         # the docstring for opacus.utils.module_modification.replace_all_modules()
-        # pyre-fixme[21]: Could not find name `resnet18` in `torchvision.models`.
         from torchvision.models import resnet18
 
         model = resnet18()
@@ -164,7 +160,6 @@ class DocstringExamplesTest(unittest.TestCase):
     def test_module_modification_convert_example(self):
         # IMPORTANT: When changing this code you also need to update
         # the docstring for opacus.utils.module_modification.convert_batchnorm_modules()
-        # pyre-fixme[21]: Could not find name `resnet50` in `torchvision.models`.
         from torchvision.models import resnet50
 
         model = resnet50()
